require 'fog'
require 'puppet/face'
require 'puppet/cloudpack/vmware'

Puppet::Face.define(:node_vmware, '0.0.1') do
  action :create do
    summary "Create a new VM from a template"
    description <<-'EOT'
      This action creates a new Virtual Machine by cloning an existing VMware
      VM marked as a template.
    EOT

    returns 'Hash containing attributes about the new Virtual Machine.'

    examples <<-'EOT'
      $ puppet node_vmware create --name jefftest --template /Datacenters/Solutions/vm/el56
    EOT

    option '--name=', '-n=' do
      required
      summary 'The name of the new VM.'
      description <<-'EOT'
        The name of the new VM to create.  This name must be unique within the
        folder containing the source VM or template.
      EOT
    end

    option '--template=', '-t=' do
      required
      summary 'The path of the template to clone from.'
      description <<-'EOT'
        The path of the VMware virtual machine template to clone.  A full path
        to the template is expected in the same format as displayed from the
        list action.
      EOT
    end

    option '--wait', '-w' do
      summary 'Wait for the clone operation to finish.'
      description <<-'EOT'
        If this option is specified then Puppet will wait for the VMware copy
        operation to finish.  This could be a lengthy process but provides the
        ability to reliably wait until the VM has finished cloning before
        moving on.
      EOT
    end
    option '--wait-for-boot', '-i' do
      summary 'Wait for the clone to boot and obtain an IP.'
      description <<-'EOT'
        If this option is specified then Puppet will wait for the VMware copy
        to finish and the VM to boot and obtain an IP address on the network.
        This requires the VMware Tools installed in the guest VM.  This option
        implies the --wait option.
      EOT
    end

    Puppet::CloudPack::VMware.add_timeout_option(self)

    when_invoked do |options|
      options[:wait] = true if options[:wait_for_boot]
      Puppet::CloudPack::VMware.create(options)
    end

    when_rendering :console do |return_value|
      return_value.to_yaml
    end
  end
end
